# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/material_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import material_pb2 as eolymp_dot_course_dot_material__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/course/material_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/course/material.proto\x1a eolymp/wellknown/direction.proto\"S\n\x13\x43reateMaterialInput\x12)\n\x08material\x18\x01 \x01(\x0b\x32\x17.eolymp.course.Material\x12\x11\n\tmodule_id\x18\x02 \x01(\t\"+\n\x14\x43reateMaterialOutput\x12\x13\n\x0bmaterial_id\x18\x01 \x01(\t\"\xf4\x01\n\x13UpdateMaterialInput\x12\x37\n\x05patch\x18\x01 \x03(\x0e\x32(.eolymp.course.UpdateMaterialInput.Patch\x12\x13\n\x0bmaterial_id\x18\x02 \x01(\t\x12)\n\x08material\x18\x03 \x01(\x0b\x32\x17.eolymp.course.Material\"d\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\r\n\tIMAGE_URL\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\t\n\x05\x44\x45PTH\x10\x05\x12\x0b\n\x07\x43ONTENT\x10\x06\x12\x0b\n\x07GRADING\x10\x07\"\x16\n\x14UpdateMaterialOutput\"e\n\x11MoveMaterialInput\x12\x13\n\x0bmaterial_id\x18\x01 \x01(\t\x12\x15\n\rnew_module_id\x18\x02 \x01(\t\x12\x11\n\tnew_index\x18\x03 \x01(\r\x12\x11\n\tnew_depth\x18\x04 \x01(\r\"\x14\n\x12MoveMaterialOutput\"*\n\x13\x44\x65leteMaterialInput\x12\x13\n\x0bmaterial_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteMaterialOutput\"n\n\x15\x44\x65scribeMaterialInput\x12\x13\n\x0bmaterial_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.course.Material.Extra\"C\n\x16\x44\x65scribeMaterialOutput\x12)\n\x08material\x18\x01 \x01(\x0b\x32\x17.eolymp.course.Material\"\xd0\x02\n\x12ListMaterialsInput\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12\x11\n\tmember_id\x18\x05 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.course.ListMaterialsInput.Filter\x12\x34\n\x04sort\x18\x32 \x01(\x0e\x32&.eolymp.course.ListMaterialsInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.course.Material.Extra\x1a\x17\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\"\x11\n\x04Sort\x12\t\n\x05INDEX\x10\x00\"L\n\x13ListMaterialsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.course.Material2\xe5\x07\n\x0fMaterialService\x12\x97\x01\n\x0e\x43reateMaterial\x12\".eolymp.course.CreateMaterialInput\x1a#.eolymp.course.CreateMaterialOutput\"<\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0c\"\n/materials\x12\xa5\x01\n\x0eUpdateMaterial\x12\".eolymp.course.UpdateMaterialInput\x1a#.eolymp.course.UpdateMaterialOutput\"J\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1a\x1a\x18/materials/{material_id}\x12\xa4\x01\n\x0cMoveMaterial\x12 .eolymp.course.MoveMaterialInput\x1a!.eolymp.course.MoveMaterialOutput\"O\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1f\"\x1d/materials/{material_id}/move\x12\xa5\x01\n\x0e\x44\x65leteMaterial\x12\".eolymp.course.DeleteMaterialInput\x1a#.eolymp.course.DeleteMaterialOutput\"J\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1a*\x18/materials/{material_id}\x12\xaa\x01\n\x10\x44\x65scribeMaterial\x12$.eolymp.course.DescribeMaterialInput\x1a%.eolymp.course.DescribeMaterialOutput\"I\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1a\x12\x18/materials/{material_id}\x12\x93\x01\n\rListMaterials\x12!.eolymp.course.ListMaterialsInput\x1a\".eolymp.course.ListMaterialsOutput\";\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0c\x12\n/materialsB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.material_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _MATERIALSERVICE.methods_by_name['CreateMaterial']._options = None
  _MATERIALSERVICE.methods_by_name['CreateMaterial']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\014\"\n/materials'
  _MATERIALSERVICE.methods_by_name['UpdateMaterial']._options = None
  _MATERIALSERVICE.methods_by_name['UpdateMaterial']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\032\032\030/materials/{material_id}'
  _MATERIALSERVICE.methods_by_name['MoveMaterial']._options = None
  _MATERIALSERVICE.methods_by_name['MoveMaterial']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\037\"\035/materials/{material_id}/move'
  _MATERIALSERVICE.methods_by_name['DeleteMaterial']._options = None
  _MATERIALSERVICE.methods_by_name['DeleteMaterial']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\032*\030/materials/{material_id}'
  _MATERIALSERVICE.methods_by_name['DescribeMaterial']._options = None
  _MATERIALSERVICE.methods_by_name['DescribeMaterial']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\032\022\030/materials/{material_id}'
  _MATERIALSERVICE.methods_by_name['ListMaterials']._options = None
  _MATERIALSERVICE.methods_by_name['ListMaterials']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\014\022\n/materials'
  _CREATEMATERIALINPUT._serialized_start=218
  _CREATEMATERIALINPUT._serialized_end=301
  _CREATEMATERIALOUTPUT._serialized_start=303
  _CREATEMATERIALOUTPUT._serialized_end=346
  _UPDATEMATERIALINPUT._serialized_start=349
  _UPDATEMATERIALINPUT._serialized_end=593
  _UPDATEMATERIALINPUT_PATCH._serialized_start=493
  _UPDATEMATERIALINPUT_PATCH._serialized_end=593
  _UPDATEMATERIALOUTPUT._serialized_start=595
  _UPDATEMATERIALOUTPUT._serialized_end=617
  _MOVEMATERIALINPUT._serialized_start=619
  _MOVEMATERIALINPUT._serialized_end=720
  _MOVEMATERIALOUTPUT._serialized_start=722
  _MOVEMATERIALOUTPUT._serialized_end=742
  _DELETEMATERIALINPUT._serialized_start=744
  _DELETEMATERIALINPUT._serialized_end=786
  _DELETEMATERIALOUTPUT._serialized_start=788
  _DELETEMATERIALOUTPUT._serialized_end=810
  _DESCRIBEMATERIALINPUT._serialized_start=812
  _DESCRIBEMATERIALINPUT._serialized_end=922
  _DESCRIBEMATERIALOUTPUT._serialized_start=924
  _DESCRIBEMATERIALOUTPUT._serialized_end=991
  _LISTMATERIALSINPUT._serialized_start=994
  _LISTMATERIALSINPUT._serialized_end=1330
  _LISTMATERIALSINPUT_FILTER._serialized_start=1288
  _LISTMATERIALSINPUT_FILTER._serialized_end=1311
  _LISTMATERIALSINPUT_SORT._serialized_start=1313
  _LISTMATERIALSINPUT_SORT._serialized_end=1330
  _LISTMATERIALSOUTPUT._serialized_start=1332
  _LISTMATERIALSOUTPUT._serialized_end=1408
  _MATERIALSERVICE._serialized_start=1411
  _MATERIALSERVICE._serialized_end=2408
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class TestingServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def UpdateTestingConfig(self, request, **kwargs):
        path = "/testing"

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateTestingConfigOutput"),
            **kwargs,
        )

    def DescribeTestingConfig(self, request, **kwargs):
        path = "/testing"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeTestingConfigOutput"),
            **kwargs,
        )

    def UpdateChecker(self, request, **kwargs):
        path = "/checker"

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateCheckerOutput"),
            **kwargs,
        )

    def DescribeChecker(self, request, **kwargs):
        path = "/checker"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeCheckerOutput"),
            **kwargs,
        )

    def UpdateInteractor(self, request, **kwargs):
        path = "/interactor"

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateInteractorOutput"),
            **kwargs,
        )

    def DescribeInteractor(self, request, **kwargs):
        path = "/interactor"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeInteractorOutput"),
            **kwargs,
        )

    def CreateTestset(self, request, **kwargs):
        path = "/testsets"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateTestsetOutput"),
            **kwargs,
        )

    def UpdateTestset(self, request, **kwargs):
        path = "/testsets/"+urllib.parse.quote(request.testset_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.testset_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateTestsetOutput"),
            **kwargs,
        )

    def DeleteTestset(self, request, **kwargs):
        path = "/testsets/"+urllib.parse.quote(request.testset_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.testset_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteTestsetOutput"),
            **kwargs,
        )

    def DescribeTestset(self, request, **kwargs):
        path = "/testsets/"+urllib.parse.quote(request.testset_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.testset_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeTestsetOutput"),
            **kwargs,
        )

    def ListTestsets(self, request, **kwargs):
        path = "/testsets"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListTestsetsOutput"),
            **kwargs,
        )

    def CreateTest(self, request, **kwargs):
        path = "/testsets/"+urllib.parse.quote(request.testset_id)+"/tests"

        # Cleanup URL parameters to avoid any ambiguity
        request.testset_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.CreateTestOutput"),
            **kwargs,
        )

    def UpdateTest(self, request, **kwargs):
        path = "/testsets/"+urllib.parse.quote(request.testset_id)+"/tests/"+urllib.parse.quote(request.test_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.testset_id = ""
        request.test_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.UpdateTestOutput"),
            **kwargs,
        )

    def DeleteTest(self, request, **kwargs):
        path = "/testsets/"+urllib.parse.quote(request.testset_id)+"/tests/"+urllib.parse.quote(request.test_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.testset_id = ""
        request.test_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DeleteTestOutput"),
            **kwargs,
        )

    def DescribeTest(self, request, **kwargs):
        path = "/testsets/"+urllib.parse.quote(request.testset_id)+"/tests/"+urllib.parse.quote(request.test_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.testset_id = ""
        request.test_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.DescribeTestOutput"),
            **kwargs,
        )

    def ListTests(self, request, **kwargs):
        path = "/testsets/"+urllib.parse.quote(request.testset_id)+"/tests"

        # Cleanup URL parameters to avoid any ambiguity
        request.testset_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListTestsOutput"),
            **kwargs,
        )

    def ListExamples(self, request, **kwargs):
        path = "/examples"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.atlas.ListExamplesOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/problem_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.judge import problem_pb2 as eolymp_dot_judge_dot_problem__pb2
from eolymp.judge import template_pb2 as eolymp_dot_judge_dot_template__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/judge/problem_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1a\x65olymp/judge/problem.proto\x1a\x1b\x65olymp/judge/template.proto\"\x7f\n\x12ImportProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\timport_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\n \x01(\r\x12\x14\n\x0csubmit_limit\x18\x0b \x01(\r\x12\x1d\n\x15score_by_best_testset\x18\x0c \x01(\x08\")\n\x13ImportProblemOutput\x12\x12\n\nproblem_id\x18\x02 \x01(\t\":\n\x10SyncProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"\x13\n\x11SyncProblemOutput\"\x80\x01\n\x12UpdateProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\n \x01(\r\x12\x14\n\x0csubmit_limit\x18\x0b \x01(\r\x12\x1d\n\x15score_by_best_testset\x18\x0c \x01(\x08\"\x15\n\x13UpdateProblemOutput\"<\n\x12\x44\x65leteProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteProblemOutput\"E\n\x11ListProblemsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"I\n\x12ListProblemsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.judge.Problem\">\n\x14\x44\x65scribeProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"?\n\x15\x44\x65scribeProblemOutput\x12&\n\x07problem\x18\x01 \x01(\x0b\x32\x15.eolymp.judge.Problem\"n\n\x19\x44\x65scribeCodeTemplateInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x13\n\x0btemplate_id\x18\x03 \x01(\t\x12\x14\n\x0ctemplate_ern\x18\x04 \x01(\t\"F\n\x1a\x44\x65scribeCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.judge.Template\"h\n\x17LookupCodeTemplateInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x14\n\x0bproblem_ern\x18\xe7\x07 \x01(\t\x12\x0f\n\x07runtime\x18\n \x01(\t\"D\n\x18LookupCodeTemplateOutput\x12(\n\x08template\x18\x01 \x01(\x0b\x32\x16.eolymp.judge.Template\"=\n\x13ListStatementsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"U\n\x14ListStatementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.eolymp.judge.Problem.Statement\">\n\x14ListAttachmentsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"W\n\x15ListAttachmentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .eolymp.judge.Problem.Attachment\";\n\x11ListExamplesInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"N\n\x12ListExamplesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.eolymp.judge.Problem.Test2\xcf\x0e\n\x0eProblemService\x12\x91\x01\n\rImportProblem\x12 .eolymp.judge.ImportProblemInput\x1a!.eolymp.judge.ImportProblemOutput\";\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0b\"\t/problems\x12\x9d\x01\n\x0bSyncProblem\x12\x1e.eolymp.judge.SyncProblemInput\x1a\x1f.eolymp.judge.SyncProblemOutput\"M\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1d\"\x1b/problems/{problem_id}/sync\x12\x9e\x01\n\rUpdateProblem\x12 .eolymp.judge.UpdateProblemInput\x1a!.eolymp.judge.UpdateProblemOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x18\"\x16/problems/{problem_id}\x12\x8d\x01\n\x0cListProblems\x12\x1f.eolymp.judge.ListProblemsInput\x1a .eolymp.judge.ListProblemsOutput\":\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00@@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0b\x12\t/problems\x12\xa4\x01\n\x0f\x44\x65scribeProblem\x12\".eolymp.judge.DescribeProblemInput\x1a#.eolymp.judge.DescribeProblemOutput\"H\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x18\x12\x16/problems/{problem_id}\x12\x9e\x01\n\rDeleteProblem\x12 .eolymp.judge.DeleteProblemInput\x1a!.eolymp.judge.DeleteProblemOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x18*\x16/problems/{problem_id}\x12\xbc\x01\n\x12LookupCodeTemplate\x12%.eolymp.judge.LookupCodeTemplateInput\x1a&.eolymp.judge.LookupCodeTemplateOutput\"W\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02(\x12&/problems/{problem_id}/lookup-template\x12\xca\x01\n\x14\x44\x65scribeCodeTemplate\x12\'.eolymp.judge.DescribeCodeTemplateInput\x1a(.eolymp.judge.DescribeCodeTemplateOutput\"_\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x30\x12./problems/{problem_id}/templates/{template_id}\x12\xab\x01\n\x0eListStatements\x12!.eolymp.judge.ListStatementsInput\x1a\".eolymp.judge.ListStatementsOutput\"R\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02#\x12!/problems/{problem_id}/statements\x12\xaf\x01\n\x0fListAttachments\x12\".eolymp.judge.ListAttachmentsInput\x1a#.eolymp.judge.ListAttachmentsOutput\"S\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02$\x12\"/problems/{problem_id}/attachments\x12\xa3\x01\n\x0cListExamples\x12\x1f.eolymp.judge.ListExamplesInput\x1a .eolymp.judge.ListExamplesOutput\"P\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02!\x12\x1f/problems/{problem_id}/examplesB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.problem_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _PROBLEMSERVICE.methods_by_name['ImportProblem']._options = None
  _PROBLEMSERVICE.methods_by_name['ImportProblem']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\013\"\t/problems'
  _PROBLEMSERVICE.methods_by_name['SyncProblem']._options = None
  _PROBLEMSERVICE.methods_by_name['SyncProblem']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\035\"\033/problems/{problem_id}/sync'
  _PROBLEMSERVICE.methods_by_name['UpdateProblem']._options = None
  _PROBLEMSERVICE.methods_by_name['UpdateProblem']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\030\"\026/problems/{problem_id}'
  _PROBLEMSERVICE.methods_by_name['ListProblems']._options = None
  _PROBLEMSERVICE.methods_by_name['ListProblems']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000@@\370\342\n\n\202\323\344\223\002\013\022\t/problems'
  _PROBLEMSERVICE.methods_by_name['DescribeProblem']._options = None
  _PROBLEMSERVICE.methods_by_name['DescribeProblem']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001\202\323\344\223\002\030\022\026/problems/{problem_id}'
  _PROBLEMSERVICE.methods_by_name['DeleteProblem']._options = None
  _PROBLEMSERVICE.methods_by_name['DeleteProblem']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\030*\026/problems/{problem_id}'
  _PROBLEMSERVICE.methods_by_name['LookupCodeTemplate']._options = None
  _PROBLEMSERVICE.methods_by_name['LookupCodeTemplate']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002(\022&/problems/{problem_id}/lookup-template'
  _PROBLEMSERVICE.methods_by_name['DescribeCodeTemplate']._options = None
  _PROBLEMSERVICE.methods_by_name['DescribeCodeTemplate']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0020\022./problems/{problem_id}/templates/{template_id}'
  _PROBLEMSERVICE.methods_by_name['ListStatements']._options = None
  _PROBLEMSERVICE.methods_by_name['ListStatements']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002#\022!/problems/{problem_id}/statements'
  _PROBLEMSERVICE.methods_by_name['ListAttachments']._options = None
  _PROBLEMSERVICE.methods_by_name['ListAttachments']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002$\022\"/problems/{problem_id}/attachments'
  _PROBLEMSERVICE.methods_by_name['ListExamples']._options = None
  _PROBLEMSERVICE.methods_by_name['ListExamples']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002!\022\037/problems/{problem_id}/examples'
  _IMPORTPROBLEMINPUT._serialized_start=208
  _IMPORTPROBLEMINPUT._serialized_end=335
  _IMPORTPROBLEMOUTPUT._serialized_start=337
  _IMPORTPROBLEMOUTPUT._serialized_end=378
  _SYNCPROBLEMINPUT._serialized_start=380
  _SYNCPROBLEMINPUT._serialized_end=438
  _SYNCPROBLEMOUTPUT._serialized_start=440
  _SYNCPROBLEMOUTPUT._serialized_end=459
  _UPDATEPROBLEMINPUT._serialized_start=462
  _UPDATEPROBLEMINPUT._serialized_end=590
  _UPDATEPROBLEMOUTPUT._serialized_start=592
  _UPDATEPROBLEMOUTPUT._serialized_end=613
  _DELETEPROBLEMINPUT._serialized_start=615
  _DELETEPROBLEMINPUT._serialized_end=675
  _DELETEPROBLEMOUTPUT._serialized_start=677
  _DELETEPROBLEMOUTPUT._serialized_end=698
  _LISTPROBLEMSINPUT._serialized_start=700
  _LISTPROBLEMSINPUT._serialized_end=769
  _LISTPROBLEMSOUTPUT._serialized_start=771
  _LISTPROBLEMSOUTPUT._serialized_end=844
  _DESCRIBEPROBLEMINPUT._serialized_start=846
  _DESCRIBEPROBLEMINPUT._serialized_end=908
  _DESCRIBEPROBLEMOUTPUT._serialized_start=910
  _DESCRIBEPROBLEMOUTPUT._serialized_end=973
  _DESCRIBECODETEMPLATEINPUT._serialized_start=975
  _DESCRIBECODETEMPLATEINPUT._serialized_end=1085
  _DESCRIBECODETEMPLATEOUTPUT._serialized_start=1087
  _DESCRIBECODETEMPLATEOUTPUT._serialized_end=1157
  _LOOKUPCODETEMPLATEINPUT._serialized_start=1159
  _LOOKUPCODETEMPLATEINPUT._serialized_end=1263
  _LOOKUPCODETEMPLATEOUTPUT._serialized_start=1265
  _LOOKUPCODETEMPLATEOUTPUT._serialized_end=1333
  _LISTSTATEMENTSINPUT._serialized_start=1335
  _LISTSTATEMENTSINPUT._serialized_end=1396
  _LISTSTATEMENTSOUTPUT._serialized_start=1398
  _LISTSTATEMENTSOUTPUT._serialized_end=1483
  _LISTATTACHMENTSINPUT._serialized_start=1485
  _LISTATTACHMENTSINPUT._serialized_end=1547
  _LISTATTACHMENTSOUTPUT._serialized_start=1549
  _LISTATTACHMENTSOUTPUT._serialized_end=1636
  _LISTEXAMPLESINPUT._serialized_start=1638
  _LISTEXAMPLESINPUT._serialized_end=1697
  _LISTEXAMPLESOUTPUT._serialized_start=1699
  _LISTEXAMPLESOUTPUT._serialized_end=1777
  _PROBLEMSERVICE._serialized_start=1780
  _PROBLEMSERVICE._serialized_end=3651
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/executor_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.executor import task_pb2 as eolymp_dot_executor_dot_task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/executor/executor_service.proto\x12\x0f\x65olymp.executor\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1a\x65olymp/executor/task.proto\"6\n\x0f\x43reateTaskInput\x12#\n\x04task\x18\x01 \x01(\x0b\x32\x15.eolymp.executor.Task\"\x12\n\x10\x43reateTaskOutput2v\n\x0f\x45xecutorService\x12\x63\n\nCreateTask\x12 .eolymp.executor.CreateTaskInput\x1a!.eolymp.executor.CreateTaskOutput\"\x10\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xc8\x01\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.executor_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _EXECUTORSERVICE.methods_by_name['CreateTask']._options = None
  _EXECUTORSERVICE.methods_by_name['CreateTask']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\310\001'
  _CREATETASKINPUT._serialized_start=123
  _CREATETASKINPUT._serialized_end=177
  _CREATETASKOUTPUT._serialized_start=179
  _CREATETASKOUTPUT._serialized_end=197
  _EXECUTORSERVICE._serialized_start=199
  _EXECUTORSERVICE._serialized_end=317
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import achievement_pb2 as _achievement_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AssignAchievementInput(_message.Message):
    __slots__ = ["achievement_id", "inc_by", "set_to"]
    ACHIEVEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    INC_BY_FIELD_NUMBER: _ClassVar[int]
    SET_TO_FIELD_NUMBER: _ClassVar[int]
    achievement_id: str
    inc_by: int
    set_to: int
    def __init__(self, achievement_id: _Optional[str] = ..., set_to: _Optional[int] = ..., inc_by: _Optional[int] = ...) -> None: ...

class AssignAchievementOutput(_message.Message):
    __slots__ = ["quantity"]
    QUANTITY_FIELD_NUMBER: _ClassVar[int]
    quantity: int
    def __init__(self, quantity: _Optional[int] = ...) -> None: ...

class ListAchievementsInput(_message.Message):
    __slots__ = ["after", "extra", "filters", "locale", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "query"]
        ID_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        query: str
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    AFTER_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    after: str
    extra: _containers.RepeatedScalarFieldContainer[_achievement_pb2.Achievement.Extra]
    filters: ListAchievementsInput.Filter
    locale: str
    offset: int
    size: int
    def __init__(self, locale: _Optional[str] = ..., after: _Optional[str] = ..., size: _Optional[int] = ..., offset: _Optional[int] = ..., filters: _Optional[_Union[ListAchievementsInput.Filter, _Mapping]] = ..., extra: _Optional[_Iterable[_Union[_achievement_pb2.Achievement.Extra, str]]] = ...) -> None: ...

class ListAchievementsOutput(_message.Message):
    __slots__ = ["items", "next_page_cursor", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_CURSOR_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_achievement_pb2.Achievement]
    next_page_cursor: str
    total: int
    def __init__(self, total: _Optional[int] = ..., next_page_cursor: _Optional[str] = ..., items: _Optional[_Iterable[_Union[_achievement_pb2.Achievement, _Mapping]]] = ...) -> None: ...

class UnassignAchievementInput(_message.Message):
    __slots__ = ["achievement_id"]
    ACHIEVEMENT_ID_FIELD_NUMBER: _ClassVar[int]
    achievement_id: str
    def __init__(self, achievement_id: _Optional[str] = ...) -> None: ...

class UnassignAchievementOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Contest(_message.Message):
    __slots__ = ["appearance", "duration", "ends_at", "ends_in", "environment", "featured_until", "format", "id", "join_unofficially", "key", "links", "logo_url", "name", "participant_count", "participant_count_hidden", "participation_mode", "problem_count", "problem_count_hidden", "scoreboard", "starts_at", "starts_in", "status", "taxonomy", "upsolve", "url", "visibility"]
    class Format(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class ParticipationMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Appearance(_message.Message):
        __slots__ = ["description", "logo_url", "title"]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        LOGO_URL_FIELD_NUMBER: _ClassVar[int]
        TITLE_FIELD_NUMBER: _ClassVar[int]
        description: str
        logo_url: str
        title: str
        def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., logo_url: _Optional[str] = ...) -> None: ...
    class Environment(_message.Message):
        __slots__ = ["allowed_runtimes"]
        ALLOWED_RUNTIMES_FIELD_NUMBER: _ClassVar[int]
        allowed_runtimes: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, allowed_runtimes: _Optional[_Iterable[str]] = ...) -> None: ...
    class LinksEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class Scoreboard(_message.Message):
        __slots__ = ["attempt_penalty", "freezing_time", "no_spoiler_ui", "share_key", "tie_breaker", "unfreeze_delay", "visibility"]
        class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        ATTEMPT_PENALTY_FIELD_NUMBER: _ClassVar[int]
        FREEZING_TIME_FIELD_NUMBER: _ClassVar[int]
        INTERNAL: Contest.Scoreboard.Visibility
        INVISIBLE: Contest.Scoreboard.Visibility
        NO_SPOILER_UI_FIELD_NUMBER: _ClassVar[int]
        PUBLIC: Contest.Scoreboard.Visibility
        SHARE_KEY_FIELD_NUMBER: _ClassVar[int]
        TIE_BREAKER_FIELD_NUMBER: _ClassVar[int]
        UNFREEZE_DELAY_FIELD_NUMBER: _ClassVar[int]
        UNKNOWN_VISIBILITY: Contest.Scoreboard.Visibility
        VISIBILITY_FIELD_NUMBER: _ClassVar[int]
        attempt_penalty: int
        freezing_time: int
        no_spoiler_ui: bool
        share_key: str
        tie_breaker: str
        unfreeze_delay: int
        visibility: Contest.Scoreboard.Visibility
        def __init__(self, visibility: _Optional[_Union[Contest.Scoreboard.Visibility, str]] = ..., freezing_time: _Optional[int] = ..., unfreeze_delay: _Optional[int] = ..., attempt_penalty: _Optional[int] = ..., tie_breaker: _Optional[str] = ..., no_spoiler_ui: bool = ..., share_key: _Optional[str] = ...) -> None: ...
    class Taxonomy(_message.Message):
        __slots__ = ["city", "country", "difficulty", "region", "scale", "series", "year"]
        class Scale(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        CITY_FIELD_NUMBER: _ClassVar[int]
        COUNTRY_FIELD_NUMBER: _ClassVar[int]
        DIFFICULTY_FIELD_NUMBER: _ClassVar[int]
        INTERNATIONAL: Contest.Taxonomy.Scale
        LOCAL: Contest.Taxonomy.Scale
        NATIONAL: Contest.Taxonomy.Scale
        REGIONAL: Contest.Taxonomy.Scale
        REGION_FIELD_NUMBER: _ClassVar[int]
        SCALE_FIELD_NUMBER: _ClassVar[int]
        SERIES_FIELD_NUMBER: _ClassVar[int]
        UNKNOWN_SCALE: Contest.Taxonomy.Scale
        YEAR_FIELD_NUMBER: _ClassVar[int]
        city: str
        country: str
        difficulty: int
        region: str
        scale: Contest.Taxonomy.Scale
        series: str
        year: int
        def __init__(self, year: _Optional[int] = ..., series: _Optional[str] = ..., scale: _Optional[_Union[Contest.Taxonomy.Scale, str]] = ..., difficulty: _Optional[int] = ..., country: _Optional[str] = ..., region: _Optional[str] = ..., city: _Optional[str] = ...) -> None: ...
    class Upsolve(_message.Message):
        __slots__ = ["free_upsolve", "virtual_upsolve"]
        FREE_UPSOLVE_FIELD_NUMBER: _ClassVar[int]
        VIRTUAL_UPSOLVE_FIELD_NUMBER: _ClassVar[int]
        free_upsolve: bool
        virtual_upsolve: bool
        def __init__(self, free_upsolve: bool = ..., virtual_upsolve: bool = ...) -> None: ...
    APPEARANCE_FIELD_NUMBER: _ClassVar[int]
    COMPLETE: Contest.Status
    DURATION_FIELD_NUMBER: _ClassVar[int]
    ENDS_AT_FIELD_NUMBER: _ClassVar[int]
    ENDS_IN_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    FEATURED_UNTIL_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    FORMAT_UNKNOWN: Contest.Format
    FROZEN: Contest.Status
    ICPC: Contest.Format
    ID_FIELD_NUMBER: _ClassVar[int]
    IOI: Contest.Format
    JOIN_UNOFFICIALLY_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    LOGO_URL_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ONLINE: Contest.ParticipationMode
    OPEN: Contest.Status
    PARTICIPANT_COUNT_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_COUNT_HIDDEN_FIELD_NUMBER: _ClassVar[int]
    PARTICIPATION_MODE_FIELD_NUMBER: _ClassVar[int]
    PARTICIPATION_MODE_UNKNOWN: Contest.ParticipationMode
    PRIVATE: Contest.Visibility
    PROBLEM_COUNT_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_COUNT_HIDDEN_FIELD_NUMBER: _ClassVar[int]
    PUBLIC: Contest.Visibility
    SCHEDULED: Contest.Status
    SCOREBOARD_FIELD_NUMBER: _ClassVar[int]
    STARTS_AT_FIELD_NUMBER: _ClassVar[int]
    STARTS_IN_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    STATUS_UNKNOWN: Contest.Status
    SUSPENDED: Contest.Status
    TAXONOMY_FIELD_NUMBER: _ClassVar[int]
    UNLISTED: Contest.Visibility
    UPSOLVE_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    VIRTUAL: Contest.ParticipationMode
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_UNKNOWN: Contest.Visibility
    appearance: Contest.Appearance
    duration: int
    ends_at: _timestamp_pb2.Timestamp
    ends_in: int
    environment: Contest.Environment
    featured_until: _timestamp_pb2.Timestamp
    format: Contest.Format
    id: str
    join_unofficially: bool
    key: str
    links: _containers.ScalarMap[str, str]
    logo_url: str
    name: str
    participant_count: int
    participant_count_hidden: bool
    participation_mode: Contest.ParticipationMode
    problem_count: int
    problem_count_hidden: bool
    scoreboard: Contest.Scoreboard
    starts_at: _timestamp_pb2.Timestamp
    starts_in: int
    status: Contest.Status
    taxonomy: Contest.Taxonomy
    upsolve: Contest.Upsolve
    url: str
    visibility: Contest.Visibility
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., links: _Optional[_Mapping[str, str]] = ..., name: _Optional[str] = ..., logo_url: _Optional[str] = ..., starts_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., starts_in: _Optional[int] = ..., ends_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., ends_in: _Optional[int] = ..., duration: _Optional[int] = ..., status: _Optional[_Union[Contest.Status, str]] = ..., visibility: _Optional[_Union[Contest.Visibility, str]] = ..., join_unofficially: bool = ..., participation_mode: _Optional[_Union[Contest.ParticipationMode, str]] = ..., format: _Optional[_Union[Contest.Format, str]] = ..., key: _Optional[str] = ..., problem_count: _Optional[int] = ..., problem_count_hidden: bool = ..., participant_count: _Optional[int] = ..., participant_count_hidden: bool = ..., featured_until: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., taxonomy: _Optional[_Union[Contest.Taxonomy, _Mapping]] = ..., appearance: _Optional[_Union[Contest.Appearance, _Mapping]] = ..., environment: _Optional[_Union[Contest.Environment, _Mapping]] = ..., upsolve: _Optional[_Union[Contest.Upsolve, _Mapping]] = ..., scoreboard: _Optional[_Union[Contest.Scoreboard, _Mapping]] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Score(_message.Message):
    __slots__ = ["breakdown", "penalty", "score", "timestamp", "upsolve", "valid_after", "valid_until"]
    class FetchingMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Problem(_message.Message):
        __slots__ = ["attempts", "breakdown", "changed", "penalty", "percentage", "problem_id", "score", "solved", "solved_at", "solved_in"]
        ATTEMPTS_FIELD_NUMBER: _ClassVar[int]
        BREAKDOWN_FIELD_NUMBER: _ClassVar[int]
        CHANGED_FIELD_NUMBER: _ClassVar[int]
        PENALTY_FIELD_NUMBER: _ClassVar[int]
        PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
        PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        SOLVED_AT_FIELD_NUMBER: _ClassVar[int]
        SOLVED_FIELD_NUMBER: _ClassVar[int]
        SOLVED_IN_FIELD_NUMBER: _ClassVar[int]
        attempts: int
        breakdown: _containers.RepeatedCompositeFieldContainer[Score.Testset]
        changed: bool
        penalty: float
        percentage: float
        problem_id: str
        score: float
        solved: bool
        solved_at: _timestamp_pb2.Timestamp
        solved_in: int
        def __init__(self, problem_id: _Optional[str] = ..., score: _Optional[float] = ..., penalty: _Optional[float] = ..., solved: bool = ..., percentage: _Optional[float] = ..., attempts: _Optional[int] = ..., solved_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., solved_in: _Optional[int] = ..., changed: bool = ..., breakdown: _Optional[_Iterable[_Union[Score.Testset, _Mapping]]] = ...) -> None: ...
    class Testset(_message.Message):
        __slots__ = ["cost", "index", "score", "testset_id"]
        COST_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        SCORE_FIELD_NUMBER: _ClassVar[int]
        TESTSET_ID_FIELD_NUMBER: _ClassVar[int]
        cost: float
        index: int
        score: float
        testset_id: str
        def __init__(self, testset_id: _Optional[str] = ..., index: _Optional[int] = ..., cost: _Optional[float] = ..., score: _Optional[float] = ...) -> None: ...
    ACTUAL: Score.FetchingMode
    BREAKDOWN_FIELD_NUMBER: _ClassVar[int]
    FROZEN: Score.FetchingMode
    LATEST: Score.FetchingMode
    PENALTY_FIELD_NUMBER: _ClassVar[int]
    PUNCTUAL: Score.FetchingMode
    SCORE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    UPSOLVE: Score.FetchingMode
    UPSOLVE_FIELD_NUMBER: _ClassVar[int]
    VALID_AFTER_FIELD_NUMBER: _ClassVar[int]
    VALID_UNTIL_FIELD_NUMBER: _ClassVar[int]
    breakdown: _containers.RepeatedCompositeFieldContainer[Score.Problem]
    penalty: float
    score: float
    timestamp: _timestamp_pb2.Timestamp
    upsolve: bool
    valid_after: int
    valid_until: int
    def __init__(self, valid_after: _Optional[int] = ..., valid_until: _Optional[int] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., score: _Optional[float] = ..., penalty: _Optional[float] = ..., upsolve: bool = ..., breakdown: _Optional[_Iterable[_Union[Score.Problem, _Mapping]]] = ...) -> None: ...



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Module(_message.Message):
    __slots__ = ["assignment", "description", "draft", "extra", "grade", "id", "image_url", "index", "name", "progress", "url"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Assignment(_message.Message):
        __slots__ = ["assigned_at", "complete_before", "completed_at", "duration", "start_after", "started_at", "status"]
        class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        ACTIVE: Module.Assignment.Status
        ASSIGNED_AT_FIELD_NUMBER: _ClassVar[int]
        COMPLETE: Module.Assignment.Status
        COMPLETED_AT_FIELD_NUMBER: _ClassVar[int]
        COMPLETE_BEFORE_FIELD_NUMBER: _ClassVar[int]
        DURATION_FIELD_NUMBER: _ClassVar[int]
        READY: Module.Assignment.Status
        SCHEDULED: Module.Assignment.Status
        STARTED_AT_FIELD_NUMBER: _ClassVar[int]
        START_AFTER_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        UNASSIGNED: Module.Assignment.Status
        UNKNOWN_STATUS: Module.Assignment.Status
        UPSOLVE: Module.Assignment.Status
        assigned_at: _timestamp_pb2.Timestamp
        complete_before: _timestamp_pb2.Timestamp
        completed_at: _timestamp_pb2.Timestamp
        duration: int
        start_after: _timestamp_pb2.Timestamp
        started_at: _timestamp_pb2.Timestamp
        status: Module.Assignment.Status
        def __init__(self, status: _Optional[_Union[Module.Assignment.Status, str]] = ..., start_after: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., complete_before: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., duration: _Optional[int] = ..., assigned_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., started_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., completed_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    ASSIGNMENT: Module.Extra
    ASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_RENDER: Module.Extra
    DESCRIPTION_VALUE: Module.Extra
    DRAFT_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    GRADE: Module.Extra
    GRADE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROGRESS: Module.Extra
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_EXTRA: Module.Extra
    URL_FIELD_NUMBER: _ClassVar[int]
    assignment: Module.Assignment
    description: _content_pb2.Content
    draft: bool
    extra: bool
    grade: int
    id: str
    image_url: str
    index: int
    name: str
    progress: float
    url: str
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., draft: bool = ..., extra: bool = ..., name: _Optional[str] = ..., image_url: _Optional[str] = ..., index: _Optional[int] = ..., description: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., progress: _Optional[float] = ..., grade: _Optional[int] = ..., assignment: _Optional[_Union[Module.Assignment, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/statement_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import statement_pb2 as eolymp_dot_atlas_dot_statement__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/atlas/statement_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/atlas/statement.proto\"J\n\x13ListStatementsInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\x12\x0f\n\x07version\x18\x64 \x01(\r\"M\n\x14ListStatementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.atlas.Statement\"c\n\x16\x44\x65scribeStatementInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x14\n\x0cstatement_id\x18\x02 \x01(\t\x12\x0e\n\x06render\x18\x03 \x01(\x08\x12\x0f\n\x07version\x18\x64 \x01(\r\"E\n\x17\x44\x65scribeStatementOutput\x12*\n\tstatement\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"[\n\x14LookupStatementInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x0e\n\x06render\x18\x03 \x01(\x08\x12\x0f\n\x07version\x18\x64 \x01(\r\"C\n\x15LookupStatementOutput\x12*\n\tstatement\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"W\n\x15PreviewStatementInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12*\n\tstatement\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"D\n\x16PreviewStatementOutput\x12*\n\tstatement\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"V\n\x14\x43reateStatementInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12*\n\tstatement\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"-\n\x15\x43reateStatementOutput\x12\x14\n\x0cstatement_id\x18\x01 \x01(\t\"\x86\x02\n\x14UpdateStatementInput\x12\x37\n\x05patch\x18\n \x03(\x0e\x32(.eolymp.atlas.UpdateStatementInput.Patch\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x14\n\x0cstatement_id\x18\x02 \x01(\t\x12*\n\tstatement\x18\x03 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"_\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\n\n\x06LOCALE\x10\x01\x12\t\n\x05TITLE\x10\x02\x12\x0b\n\x07\x43ONTENT\x10\x03\x12\x11\n\rDOWNLOAD_LINK\x10\x04\x12\n\n\x06\x41UTHOR\x10\x05\x12\n\n\x06SOURCE\x10\x06\"\x17\n\x15UpdateStatementOutput\"@\n\x14\x44\x65leteStatementInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x14\n\x0cstatement_id\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteStatementOutput2\x81\t\n\x10StatementService\x12\x99\x01\n\x0f\x43reateStatement\x12\".eolymp.atlas.CreateStatementInput\x1a#.eolymp.atlas.CreateStatementOutput\"=\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\r\x1a\x0b/statements\x12\xa8\x01\n\x0fUpdateStatement\x12\".eolymp.atlas.UpdateStatementInput\x1a#.eolymp.atlas.UpdateStatementOutput\"L\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1c\x1a\x1a/statements/{statement_id}\x12\xa8\x01\n\x0f\x44\x65leteStatement\x12\".eolymp.atlas.DeleteStatementInput\x1a#.eolymp.atlas.DeleteStatementOutput\"L\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1c*\x1a/statements/{statement_id}\x12\xad\x01\n\x11\x44\x65scribeStatement\x12$.eolymp.atlas.DescribeStatementInput\x1a%.eolymp.atlas.DescribeStatementOutput\"K\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1c\x12\x1a/statements/{statement_id}\x12\x97\x01\n\x0fLookupStatement\x12\".eolymp.atlas.LookupStatementInput\x1a#.eolymp.atlas.LookupStatementOutput\";\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0c\x12\n/translate\x12\x98\x01\n\x10PreviewStatement\x12#.eolymp.atlas.PreviewStatementInput\x1a$.eolymp.atlas.PreviewStatementOutput\"9\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\n\"\x08/renders\x12\x95\x01\n\x0eListStatements\x12!.eolymp.atlas.ListStatementsInput\x1a\".eolymp.atlas.ListStatementsOutput\"<\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\r\x12\x0b/statementsB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.statement_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _STATEMENTSERVICE.methods_by_name['CreateStatement']._options = None
  _STATEMENTSERVICE.methods_by_name['CreateStatement']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\r\032\013/statements'
  _STATEMENTSERVICE.methods_by_name['UpdateStatement']._options = None
  _STATEMENTSERVICE.methods_by_name['UpdateStatement']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\034\032\032/statements/{statement_id}'
  _STATEMENTSERVICE.methods_by_name['DeleteStatement']._options = None
  _STATEMENTSERVICE.methods_by_name['DeleteStatement']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\034*\032/statements/{statement_id}'
  _STATEMENTSERVICE.methods_by_name['DescribeStatement']._options = None
  _STATEMENTSERVICE.methods_by_name['DescribeStatement']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\034\022\032/statements/{statement_id}'
  _STATEMENTSERVICE.methods_by_name['LookupStatement']._options = None
  _STATEMENTSERVICE.methods_by_name['LookupStatement']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\014\022\n/translate'
  _STATEMENTSERVICE.methods_by_name['PreviewStatement']._options = None
  _STATEMENTSERVICE.methods_by_name['PreviewStatement']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\n\"\010/renders'
  _STATEMENTSERVICE.methods_by_name['ListStatements']._options = None
  _STATEMENTSERVICE.methods_by_name['ListStatements']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\r\022\013/statements'
  _LISTSTATEMENTSINPUT._serialized_start=183
  _LISTSTATEMENTSINPUT._serialized_end=257
  _LISTSTATEMENTSOUTPUT._serialized_start=259
  _LISTSTATEMENTSOUTPUT._serialized_end=336
  _DESCRIBESTATEMENTINPUT._serialized_start=338
  _DESCRIBESTATEMENTINPUT._serialized_end=437
  _DESCRIBESTATEMENTOUTPUT._serialized_start=439
  _DESCRIBESTATEMENTOUTPUT._serialized_end=508
  _LOOKUPSTATEMENTINPUT._serialized_start=510
  _LOOKUPSTATEMENTINPUT._serialized_end=601
  _LOOKUPSTATEMENTOUTPUT._serialized_start=603
  _LOOKUPSTATEMENTOUTPUT._serialized_end=670
  _PREVIEWSTATEMENTINPUT._serialized_start=672
  _PREVIEWSTATEMENTINPUT._serialized_end=759
  _PREVIEWSTATEMENTOUTPUT._serialized_start=761
  _PREVIEWSTATEMENTOUTPUT._serialized_end=829
  _CREATESTATEMENTINPUT._serialized_start=831
  _CREATESTATEMENTINPUT._serialized_end=917
  _CREATESTATEMENTOUTPUT._serialized_start=919
  _CREATESTATEMENTOUTPUT._serialized_end=964
  _UPDATESTATEMENTINPUT._serialized_start=967
  _UPDATESTATEMENTINPUT._serialized_end=1229
  _UPDATESTATEMENTINPUT_PATCH._serialized_start=1134
  _UPDATESTATEMENTINPUT_PATCH._serialized_end=1229
  _UPDATESTATEMENTOUTPUT._serialized_start=1231
  _UPDATESTATEMENTOUTPUT._serialized_end=1254
  _DELETESTATEMENTINPUT._serialized_start=1256
  _DELETESTATEMENTINPUT._serialized_end=1320
  _DELETESTATEMENTOUTPUT._serialized_start=1322
  _DELETESTATEMENTOUTPUT._serialized_end=1345
  _STATEMENTSERVICE._serialized_start=1348
  _STATEMENTSERVICE._serialized_end=2501
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/problem.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/atlas/problem.proto\x12\x0c\x65olymp.atlas\"\x83\x03\n\x07Problem\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x03url\x18\xaa\x05 \x01(\t\x12\x30\n\x05links\x18\xab\x05 \x03(\x0b\x32 .eolymp.atlas.Problem.LinksEntry\x12\x0e\n\x06number\x18\n \x01(\x05\x12\x0f\n\x07visible\x18\x0b \x01(\x08\x12\x0f\n\x07private\x18\x0c \x01(\x08\x12\x0e\n\x06origin\x18\r \x01(\t\x12\x0e\n\x06topics\x18\x14 \x03(\t\x12\x17\n\x0f\x61\x63\x63\x65ptance_rate\x18( \x01(\x02\x12\x19\n\x11submissions_count\x18* \x01(\r\x12\x1c\n\x14submissions_accepted\x18+ \x01(\r\x12\x0c\n\x04vote\x18\x32 \x01(\x05\x12\x12\n\nvote_count\x18\x33 \x01(\x05\x12\x12\n\ndifficulty\x18\x15 \x01(\r\x1a,\n\nLinksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"$\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x08\n\x04VOTE\x10\x01\x42-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.problem_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _PROBLEM_LINKSENTRY._options = None
  _PROBLEM_LINKSENTRY._serialized_options = b'8\001'
  _PROBLEM._serialized_start=45
  _PROBLEM._serialized_end=432
  _PROBLEM_LINKSENTRY._serialized_start=350
  _PROBLEM_LINKSENTRY._serialized_end=394
  _PROBLEM_EXTRA._serialized_start=396
  _PROBLEM_EXTRA._serialized_end=432
# @@protoc_insertion_point(module_scope)



from eolymp.executor import file_pb2 as _file_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Script(_message.Message):
    __slots__ = ["files", "name", "runtime", "source_url"]
    FILES_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_URL_FIELD_NUMBER: _ClassVar[int]
    files: _containers.RepeatedCompositeFieldContainer[_file_pb2.File]
    name: str
    runtime: str
    source_url: str
    def __init__(self, name: _Optional[str] = ..., runtime: _Optional[str] = ..., source_url: _Optional[str] = ..., files: _Optional[_Iterable[_Union[_file_pb2.File, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Thread(_message.Message):
    __slots__ = ["id", "name", "reply_count", "url", "vote", "vote_count"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    REPLY_COUNT_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    VOTE_COUNT_FIELD_NUMBER: _ClassVar[int]
    VOTE_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    reply_count: int
    url: str
    vote: int
    vote_count: int
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., name: _Optional[str] = ..., vote: _Optional[int] = ..., vote_count: _Optional[int] = ..., reply_count: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/registration_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'eolymp/judge/registration_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/community/attribute.proto\"/\n\x19\x44\x65scribeRegistrationInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"\x80\x01\n\x1a\x44\x65scribeRegistrationOutput\x12/\n\nattributes\x18\x14 \x03(\x0b\x32\x1b.eolymp.community.Attribute\x12\x31\n\x06values\x18\x15 \x03(\x0b\x32!.eolymp.community.Attribute.Value\"`\n\x17SubmitRegistrationInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x31\n\x06values\x18\x14 \x03(\x0b\x32!.eolymp.community.Attribute.Value\"\x1a\n\x18SubmitRegistrationOutput2\xf5\x02\n\x13RegistrationService\x12\xb0\x01\n\x14\x44\x65scribeRegistration\x12\'.eolymp.judge.DescribeRegistrationInput\x1a(.eolymp.judge.DescribeRegistrationOutput\"E\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x0f\x12\r/registration\x12\xaa\x01\n\x12SubmitRegistration\x12%.eolymp.judge.SubmitRegistrationInput\x1a&.eolymp.judge.SubmitRegistrationOutput\"E\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xd3\xe4\x93\x02\x0f\"\r/registrationB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.registration_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _REGISTRATIONSERVICE.methods_by_name['DescribeRegistration']._options = None
  _REGISTRATIONSERVICE.methods_by_name['DescribeRegistration']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\323\344\223\002\017\022\r/registration'
  _REGISTRATIONSERVICE.methods_by_name['SubmitRegistration']._options = None
  _REGISTRATIONSERVICE.methods_by_name['SubmitRegistration']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\323\344\223\002\017\"\r/registration'
  _DESCRIBEREGISTRATIONINPUT._serialized_start=190
  _DESCRIBEREGISTRATIONINPUT._serialized_end=237
  _DESCRIBEREGISTRATIONOUTPUT._serialized_start=240
  _DESCRIBEREGISTRATIONOUTPUT._serialized_end=368
  _SUBMITREGISTRATIONINPUT._serialized_start=370
  _SUBMITREGISTRATIONINPUT._serialized_end=466
  _SUBMITREGISTRATIONOUTPUT._serialized_start=468
  _SUBMITREGISTRATIONOUTPUT._serialized_end=494
  _REGISTRATIONSERVICE._serialized_start=497
  _REGISTRATIONSERVICE._serialized_end=870
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/mailing/email_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65olymp/mailing/email_type.proto\x12\x0e\x65olymp.mailing*b\n\tEmailType\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x0b\n\x07\x41\x43\x43OUNT\x10\x01\x12\x0e\n\nNEWSLETTER\x10\x02\x12\x0b\n\x07UPDATES\x10\x03\x12\x0e\n\nCOMMERCIAL\x10\x04\x12\t\n\x05OTHER\x10\x05\x42\x31Z/github.com/eolymp/go-sdk/eolymp/mailing;mailingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.mailing.email_type_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/mailing;mailing'
  _EMAILTYPE._serialized_start=51
  _EMAILTYPE._serialized_end=149
# @@protoc_insertion_point(module_scope)



from eolymp.judge import medal_pb2 as _medal_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Participant(_message.Message):
    __slots__ = ["bonus_time", "contest_id", "disqualified", "end_at", "end_in", "ghost", "id", "inactive", "medal", "member_id", "name", "passcode", "started_at", "started_in", "status", "submits", "unofficial"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Submit(_message.Message):
        __slots__ = ["counter", "problem_id"]
        COUNTER_FIELD_NUMBER: _ClassVar[int]
        PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
        counter: int
        problem_id: str
        def __init__(self, problem_id: _Optional[str] = ..., counter: _Optional[int] = ...) -> None: ...
    ACTIVE: Participant.Status
    BLOCKED: Participant.Status
    BONUS_TIME_FIELD_NUMBER: _ClassVar[int]
    COMPLETE: Participant.Status
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    DISQUALIFIED_FIELD_NUMBER: _ClassVar[int]
    END_AT_FIELD_NUMBER: _ClassVar[int]
    END_IN_FIELD_NUMBER: _ClassVar[int]
    GHOST_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    INACTIVE_FIELD_NUMBER: _ClassVar[int]
    MEDAL_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PASSCODE_FIELD_NUMBER: _ClassVar[int]
    READY: Participant.Status
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    STARTED_IN_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SUBMITS_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_STATUS: Participant.Status
    UNOFFICIAL_FIELD_NUMBER: _ClassVar[int]
    UPSOLVE: Participant.Status
    WAITING: Participant.Status
    bonus_time: int
    contest_id: str
    disqualified: bool
    end_at: _timestamp_pb2.Timestamp
    end_in: int
    ghost: bool
    id: str
    inactive: bool
    medal: _medal_pb2.Medal
    member_id: str
    name: str
    passcode: str
    started_at: _timestamp_pb2.Timestamp
    started_in: int
    status: Participant.Status
    submits: _containers.RepeatedCompositeFieldContainer[Participant.Submit]
    unofficial: bool
    def __init__(self, id: _Optional[str] = ..., contest_id: _Optional[str] = ..., member_id: _Optional[str] = ..., name: _Optional[str] = ..., unofficial: bool = ..., inactive: bool = ..., disqualified: bool = ..., ghost: bool = ..., medal: _Optional[_Union[_medal_pb2.Medal, str]] = ..., status: _Optional[_Union[Participant.Status, str]] = ..., started_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., started_in: _Optional[int] = ..., end_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., end_in: _Optional[int] = ..., bonus_time: _Optional[int] = ..., passcode: _Optional[str] = ..., submits: _Optional[_Iterable[_Union[Participant.Submit, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/acl/entitlement_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/acl/entitlement_service.proto\x12\neolymp.acl\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\"\x1d\n\x1bIntrospectEntitlementsInput\"4\n\x1cIntrospectEntitlementsOutput\x12\x14\n\x0c\x65ntitlements\x18\x01 \x03(\t2\xaa\x01\n\x12\x45ntitlementService\x12\x93\x01\n\x16IntrospectEntitlements\x12\'.eolymp.acl.IntrospectEntitlementsInput\x1a(.eolymp.acl.IntrospectEntitlementsOutput\"&\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x11\x12\x0f/__entitlementsB)Z\'github.com/eolymp/go-sdk/eolymp/acl;aclb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.acl.entitlement_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\'github.com/eolymp/go-sdk/eolymp/acl;acl'
  _ENTITLEMENTSERVICE.methods_by_name['IntrospectEntitlements']._options = None
  _ENTITLEMENTSERVICE.methods_by_name['IntrospectEntitlements']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n\024\202\323\344\223\002\021\022\017/__entitlements'
  _INTROSPECTENTITLEMENTSINPUT._serialized_start=119
  _INTROSPECTENTITLEMENTSINPUT._serialized_end=148
  _INTROSPECTENTITLEMENTSOUTPUT._serialized_start=150
  _INTROSPECTENTITLEMENTSOUTPUT._serialized_end=202
  _ENTITLEMENTSERVICE._serialized_start=205
  _ENTITLEMENTSERVICE._serialized_end=375
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Recipient(_message.Message):
    __slots__ = ["created_at", "delivered_at", "id", "member_id", "sent_at", "status", "updated_at"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    BOUNCED: Recipient.Status
    CREATED: Recipient.Status
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    DELIVERED: Recipient.Status
    DELIVERED_AT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    PENDING: Recipient.Status
    SENT: Recipient.Status
    SENT_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    UNKNOWN_STATUS: Recipient.Status
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    created_at: _timestamp_pb2.Timestamp
    delivered_at: _timestamp_pb2.Timestamp
    id: str
    member_id: str
    sent_at: _timestamp_pb2.Timestamp
    status: Recipient.Status
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., sent_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., delivered_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., member_id: _Optional[str] = ..., status: _Optional[_Union[Recipient.Status, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/taxonomy/geography_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.taxonomy import geography_country_pb2 as eolymp_dot_taxonomy_dot_geography__country__pb2
from eolymp.taxonomy import geography_region_pb2 as eolymp_dot_taxonomy_dot_geography__region__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'eolymp/taxonomy/geography_service.proto\x12\x0f\x65olymp.taxonomy\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\'eolymp/taxonomy/geography_country.proto\x1a&eolymp/taxonomy/geography_region.proto\x1a!eolymp/wellknown/expression.proto\"*\n\x14\x44\x65scribeCountryInput\x12\x12\n\ncountry_id\x18\x01 \x01(\t\"B\n\x15\x44\x65scribeCountryOutput\x12)\n\x07\x63ountry\x18\x01 \x01(\x0b\x32\x18.eolymp.taxonomy.Country\"\xe6\x01\n\x12ListCountriesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.taxonomy.ListCountriesInput.Filter\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"M\n\x13ListCountriesOutput\x12\'\n\x05items\x18\x01 \x03(\x0b\x32\x18.eolymp.taxonomy.Country\x12\r\n\x05total\x18\x02 \x01(\x05\"(\n\x13\x44\x65scribeRegionInput\x12\x11\n\tregion_id\x18\x01 \x01(\t\"?\n\x14\x44\x65scribeRegionOutput\x12\'\n\x06region\x18\x01 \x01(\x0b\x32\x17.eolymp.taxonomy.Region\"\x97\x02\n\x10ListRegionsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.taxonomy.ListRegionsInput.Filter\x1a\xa9\x01\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\ncountry_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x04 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"J\n\x11ListRegionsOutput\x12&\n\x05items\x18\x01 \x03(\x0b\x32\x17.eolymp.taxonomy.Region\x12\r\n\x05total\x18\x02 \x01(\x05\x32\xac\x04\n\x10GeographyService\x12~\n\rListCountries\x12#.eolymp.taxonomy.ListCountriesInput\x1a$.eolymp.taxonomy.ListCountriesOutput\"\"\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x0c\x12\n/countries\x12\x91\x01\n\x0f\x44\x65scribeCountry\x12%.eolymp.taxonomy.DescribeCountryInput\x1a&.eolymp.taxonomy.DescribeCountryOutput\"/\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x19\x12\x17/countries/{country_id}\x12v\n\x0bListRegions\x12!.eolymp.taxonomy.ListRegionsInput\x1a\".eolymp.taxonomy.ListRegionsOutput\" \xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\n\x12\x08/regions\x12\x8b\x01\n\x0e\x44\x65scribeRegion\x12$.eolymp.taxonomy.DescribeRegionInput\x1a%.eolymp.taxonomy.DescribeRegionOutput\",\xea\xe2\n\x0c\xf5\xe2\n\x00\x00HB\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x16\x12\x14/regions/{region_id}B3Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.taxonomy.geography_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomy'
  _GEOGRAPHYSERVICE.methods_by_name['ListCountries']._options = None
  _GEOGRAPHYSERVICE.methods_by_name['ListCountries']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002\014\022\n/countries'
  _GEOGRAPHYSERVICE.methods_by_name['DescribeCountry']._options = None
  _GEOGRAPHYSERVICE.methods_by_name['DescribeCountry']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002\031\022\027/countries/{country_id}'
  _GEOGRAPHYSERVICE.methods_by_name['ListRegions']._options = None
  _GEOGRAPHYSERVICE.methods_by_name['ListRegions']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002\n\022\010/regions'
  _GEOGRAPHYSERVICE.methods_by_name['DescribeRegion']._options = None
  _GEOGRAPHYSERVICE.methods_by_name['DescribeRegion']._serialized_options = b'\352\342\n\014\365\342\n\000\000HB\370\342\n\364\003\202\323\344\223\002\026\022\024/regions/{region_id}'
  _DESCRIBECOUNTRYINPUT._serialized_start=243
  _DESCRIBECOUNTRYINPUT._serialized_end=285
  _DESCRIBECOUNTRYOUTPUT._serialized_start=287
  _DESCRIBECOUNTRYOUTPUT._serialized_end=353
  _LISTCOUNTRIESINPUT._serialized_start=356
  _LISTCOUNTRIESINPUT._serialized_end=586
  _LISTCOUNTRIESINPUT_FILTER._serialized_start=469
  _LISTCOUNTRIESINPUT_FILTER._serialized_end=586
  _LISTCOUNTRIESOUTPUT._serialized_start=588
  _LISTCOUNTRIESOUTPUT._serialized_end=665
  _DESCRIBEREGIONINPUT._serialized_start=667
  _DESCRIBEREGIONINPUT._serialized_end=707
  _DESCRIBEREGIONOUTPUT._serialized_start=709
  _DESCRIBEREGIONOUTPUT._serialized_end=772
  _LISTREGIONSINPUT._serialized_start=775
  _LISTREGIONSINPUT._serialized_end=1054
  _LISTREGIONSINPUT_FILTER._serialized_start=885
  _LISTREGIONSINPUT_FILTER._serialized_end=1054
  _LISTREGIONSOUTPUT._serialized_start=1056
  _LISTREGIONSOUTPUT._serialized_end=1130
  _GEOGRAPHYSERVICE._serialized_start=1133
  _GEOGRAPHYSERVICE._serialized_end=1689
# @@protoc_insertion_point(module_scope)



from eolymp.executor import checker_pb2 as _checker_pb2
from eolymp.executor import file_pb2 as _file_pb2
from eolymp.executor import interactor_pb2 as _interactor_pb2
from eolymp.executor import script_pb2 as _script_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Task(_message.Message):
    __slots__ = ["checker", "constraints", "files", "footer_url", "header_url", "interactor", "origin", "preconditions", "priority", "redirect_stderr_to_stdout", "reference", "run_count", "runs", "runtime", "scripts", "source", "source_url"]
    class Constraint(_message.Message):
        __slots__ = ["actor", "cpu_time_limit", "file_size_limit", "memory_limit", "selector", "wall_time_limit"]
        ACTOR_FIELD_NUMBER: _ClassVar[int]
        CPU_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
        FILE_SIZE_LIMIT_FIELD_NUMBER: _ClassVar[int]
        MEMORY_LIMIT_FIELD_NUMBER: _ClassVar[int]
        SELECTOR_FIELD_NUMBER: _ClassVar[int]
        WALL_TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
        actor: str
        cpu_time_limit: int
        file_size_limit: int
        memory_limit: int
        selector: _containers.RepeatedScalarFieldContainer[str]
        wall_time_limit: int
        def __init__(self, selector: _Optional[_Iterable[str]] = ..., actor: _Optional[str] = ..., wall_time_limit: _Optional[int] = ..., cpu_time_limit: _Optional[int] = ..., memory_limit: _Optional[int] = ..., file_size_limit: _Optional[int] = ...) -> None: ...
    class Generator(_message.Message):
        __slots__ = ["arguments", "script_name"]
        ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
        SCRIPT_NAME_FIELD_NUMBER: _ClassVar[int]
        arguments: _containers.RepeatedScalarFieldContainer[str]
        script_name: str
        def __init__(self, script_name: _Optional[str] = ..., arguments: _Optional[_Iterable[str]] = ...) -> None: ...
    class Precondition(_message.Message):
        __slots__ = ["depends_on", "max_execution_time", "selector", "stop_on_failure"]
        DEPENDS_ON_FIELD_NUMBER: _ClassVar[int]
        MAX_EXECUTION_TIME_FIELD_NUMBER: _ClassVar[int]
        SELECTOR_FIELD_NUMBER: _ClassVar[int]
        STOP_ON_FAILURE_FIELD_NUMBER: _ClassVar[int]
        depends_on: _containers.RepeatedScalarFieldContainer[str]
        max_execution_time: int
        selector: _containers.RepeatedScalarFieldContainer[str]
        stop_on_failure: bool
        def __init__(self, selector: _Optional[_Iterable[str]] = ..., depends_on: _Optional[_Iterable[str]] = ..., stop_on_failure: bool = ..., max_execution_time: _Optional[int] = ...) -> None: ...
    class Run(_message.Message):
        __slots__ = ["answer_content", "answer_generator", "answer_object_id", "answer_url", "cost", "debug", "index", "input_content", "input_generator", "input_object_id", "input_url", "labels", "reference"]
        ANSWER_CONTENT_FIELD_NUMBER: _ClassVar[int]
        ANSWER_GENERATOR_FIELD_NUMBER: _ClassVar[int]
        ANSWER_OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
        ANSWER_URL_FIELD_NUMBER: _ClassVar[int]
        COST_FIELD_NUMBER: _ClassVar[int]
        DEBUG_FIELD_NUMBER: _ClassVar[int]
        INDEX_FIELD_NUMBER: _ClassVar[int]
        INPUT_CONTENT_FIELD_NUMBER: _ClassVar[int]
        INPUT_GENERATOR_FIELD_NUMBER: _ClassVar[int]
        INPUT_OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
        INPUT_URL_FIELD_NUMBER: _ClassVar[int]
        LABELS_FIELD_NUMBER: _ClassVar[int]
        REFERENCE_FIELD_NUMBER: _ClassVar[int]
        answer_content: str
        answer_generator: Task.Generator
        answer_object_id: str
        answer_url: str
        cost: float
        debug: bool
        index: int
        input_content: str
        input_generator: Task.Generator
        input_object_id: str
        input_url: str
        labels: _containers.RepeatedScalarFieldContainer[str]
        reference: str
        def __init__(self, reference: _Optional[str] = ..., index: _Optional[int] = ..., debug: bool = ..., cost: _Optional[float] = ..., labels: _Optional[_Iterable[str]] = ..., input_object_id: _Optional[str] = ..., input_content: _Optional[str] = ..., input_url: _Optional[str] = ..., input_generator: _Optional[_Union[Task.Generator, _Mapping]] = ..., answer_object_id: _Optional[str] = ..., answer_content: _Optional[str] = ..., answer_url: _Optional[str] = ..., answer_generator: _Optional[_Union[Task.Generator, _Mapping]] = ...) -> None: ...
    CHECKER_FIELD_NUMBER: _ClassVar[int]
    CONSTRAINTS_FIELD_NUMBER: _ClassVar[int]
    FILES_FIELD_NUMBER: _ClassVar[int]
    FOOTER_URL_FIELD_NUMBER: _ClassVar[int]
    HEADER_URL_FIELD_NUMBER: _ClassVar[int]
    INTERACTOR_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    PRECONDITIONS_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_STDERR_TO_STDOUT_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    RUNS_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    RUN_COUNT_FIELD_NUMBER: _ClassVar[int]
    SCRIPTS_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    SOURCE_URL_FIELD_NUMBER: _ClassVar[int]
    checker: _checker_pb2.Checker
    constraints: _containers.RepeatedCompositeFieldContainer[Task.Constraint]
    files: _containers.RepeatedCompositeFieldContainer[_file_pb2.File]
    footer_url: str
    header_url: str
    interactor: _interactor_pb2.Interactor
    origin: str
    preconditions: _containers.RepeatedCompositeFieldContainer[Task.Precondition]
    priority: int
    redirect_stderr_to_stdout: bool
    reference: str
    run_count: int
    runs: _containers.RepeatedCompositeFieldContainer[Task.Run]
    runtime: str
    scripts: _containers.RepeatedCompositeFieldContainer[_script_pb2.Script]
    source: str
    source_url: str
    def __init__(self, reference: _Optional[str] = ..., origin: _Optional[str] = ..., priority: _Optional[int] = ..., runtime: _Optional[str] = ..., source: _Optional[str] = ..., source_url: _Optional[str] = ..., header_url: _Optional[str] = ..., footer_url: _Optional[str] = ..., redirect_stderr_to_stdout: bool = ..., run_count: _Optional[int] = ..., preconditions: _Optional[_Iterable[_Union[Task.Precondition, _Mapping]]] = ..., constraints: _Optional[_Iterable[_Union[Task.Constraint, _Mapping]]] = ..., checker: _Optional[_Union[_checker_pb2.Checker, _Mapping]] = ..., interactor: _Optional[_Union[_interactor_pb2.Interactor, _Mapping]] = ..., runs: _Optional[_Iterable[_Union[Task.Run, _Mapping]]] = ..., files: _Optional[_Iterable[_Union[_file_pb2.File, _Mapping]]] = ..., scripts: _Optional[_Iterable[_Union[_script_pb2.Script, _Mapping]]] = ...) -> None: ...



from .attribute_pb2 import *
from .configuration_identity_pb2 import *
from .group_service_pb2 import *
from .account_service_http import *
from .configuration_idp_pb2 import *
from .account_service_pb2 import *
from .member_service_pb2 import *
from .achievement_pb2 import *
from .group_service_http import *
from .achievement_service_http import *
from .linked_account_pb2 import *
from .member_ghost_pb2 import *
from .attribute_service_pb2 import *
from .member_team_pb2 import *
from .attribute_service_http import *
from .configuration_service_pb2 import *
from .rating_point_pb2 import *
from .configuration_service_http import *
from .rating_service_pb2 import *
from .events_pb2 import *
from .achievement_service_pb2 import *
from .member_service_http import *
from .group_pb2 import *
from .member_pb2 import *
from .activity_graph_service_pb2 import *
from .rating_service_http import *
from .linked_account_service_http import *
from .linked_account_service_pb2 import *
from .activity_graph_service_http import *
from .member_user_pb2 import *



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/taxonomy/enum_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.taxonomy import enum_pb2 as eolymp_dot_taxonomy_dot_enum__pb2
from eolymp.taxonomy import enum_value_pb2 as eolymp_dot_taxonomy_dot_enum__value__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/taxonomy/enum_service.proto\x12\x0f\x65olymp.taxonomy\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1a\x65olymp/taxonomy/enum.proto\x1a eolymp/taxonomy/enum_value.proto\x1a!eolymp/wellknown/expression.proto\"6\n\x0f\x43reateEnumInput\x12#\n\x04\x65num\x18\x01 \x01(\x0b\x32\x15.eolymp.taxonomy.Enum\"#\n\x10\x43reateEnumOutput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\"\"\n\x0f\x44\x65leteEnumInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\"\x12\n\x10\x44\x65leteEnumOutput\"\x9a\x01\n\x0fUpdateEnumInput\x12\x35\n\x05patch\x18\x01 \x03(\x0e\x32&.eolymp.taxonomy.UpdateEnumInput.Patch\x12\x0f\n\x07\x65num_id\x18\x02 \x01(\t\x12#\n\x04\x65num\x18\x03 \x01(\x0b\x32\x15.eolymp.taxonomy.Enum\"\x1a\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\"\x12\n\x10UpdateEnumOutput\"$\n\x11\x44\x65scribeEnumInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\"9\n\x12\x44\x65scribeEnumOutput\x12#\n\x04\x65num\x18\x01 \x01(\x0b\x32\x15.eolymp.taxonomy.Enum\"\xde\x01\n\x0eListEnumsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x37\n\x07\x66ilters\x18( \x01(\x0b\x32&.eolymp.taxonomy.ListEnumsInput.Filter\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"F\n\x0fListEnumsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.taxonomy.Enum\"J\n\x10\x43reateValueInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.eolymp.taxonomy.Value\"%\n\x11\x43reateValueOutput\x12\x10\n\x08value_id\x18\x01 \x01(\t\"5\n\x10\x44\x65leteValueInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\x12\x10\n\x08value_id\x18\x02 \x01(\t\"\x13\n\x11\x44\x65leteValueOutput\"\xe0\x01\n\x10UpdateValueInput\x12\x36\n\x05patch\x18\x01 \x03(\x0e\x32\'.eolymp.taxonomy.UpdateValueInput.Patch\x12\x0f\n\x07\x65num_id\x18\x02 \x01(\t\x12\x10\n\x08value_id\x18\x03 \x01(\t\x12%\n\x05value\x18\x04 \x01(\x0b\x32\x16.eolymp.taxonomy.Value\"J\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x08\n\x04\x41\x42\x42R\x10\x02\x12\x0b\n\x07SUMMARY\x10\x03\x12\t\n\x05IMAGE\x10\x04\x12\x0c\n\x08KEYWORDS\x10\x05\"\x13\n\x11UpdateValueOutput\"G\n\x12\x44\x65scribeValueInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\x12\x10\n\x08value_id\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x64 \x01(\t\"<\n\x13\x44\x65scribeValueOutput\x12%\n\x05value\x18\x01 \x01(\x0b\x32\x16.eolymp.taxonomy.Value\"\x81\x02\n\x0fListValuesInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.taxonomy.ListValuesInput.Filter\x12\x0e\n\x06locale\x18\x64 \x01(\t\x1au\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\"H\n\x10ListValuesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.taxonomy.Value\"\x81\x01\n\x13TranslateValueInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\x12\x10\n\x08value_id\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x37\n\x0btranslation\x18\x04 \x01(\x0b\x32\".eolymp.taxonomy.Value.Translation\"\x16\n\x14TranslateValueOutput\"K\n\x16\x44\x65leteTranslationInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\x12\x10\n\x08value_id\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\"\x19\n\x17\x44\x65leteTranslationOutput\"\xd4\x01\n\x15ListTranslationsInput\x12\x0f\n\x07\x65num_id\x18\x01 \x01(\t\x12\x10\n\x08value_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.taxonomy.ListTranslationsInput.Filter\x1a:\n\x06\x46ilter\x12\x30\n\x06locale\x18\x01 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"Z\n\x16ListTranslationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x31\n\x05items\x18\x02 \x03(\x0b\x32\".eolymp.taxonomy.Value.Translation2\xa2\x10\n\x0b\x45numService\x12\x8b\x01\n\nCreateEnum\x12 .eolymp.taxonomy.CreateEnumInput\x1a!.eolymp.taxonomy.CreateEnumOutput\"8\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x08\"\x06/enums\x12\x95\x01\n\nDeleteEnum\x12 .eolymp.taxonomy.DeleteEnumInput\x1a!.eolymp.taxonomy.DeleteEnumOutput\"B\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x12*\x10/enums/{enum_id}\x12\x95\x01\n\nUpdateEnum\x12 .eolymp.taxonomy.UpdateEnumInput\x1a!.eolymp.taxonomy.UpdateEnumOutput\"B\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x12\x1a\x10/enums/{enum_id}\x12\x80\x01\n\x0c\x44\x65scribeEnum\x12\".eolymp.taxonomy.DescribeEnumInput\x1a#.eolymp.taxonomy.DescribeEnumOutput\"\'\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x12\x12\x10/enums/{enum_id}\x12m\n\tListEnums\x12\x1f.eolymp.taxonomy.ListEnumsInput\x1a .eolymp.taxonomy.ListEnumsOutput\"\x1d\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x08\x12\x06/enums\x12\x9e\x01\n\x0b\x43reateValue\x12!.eolymp.taxonomy.CreateValueInput\x1a\".eolymp.taxonomy.CreateValueOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x18\"\x16/enums/{enum_id}/items\x12\xaa\x01\n\x0b\x44\x65leteValue\x12!.eolymp.taxonomy.DeleteValueInput\x1a\".eolymp.taxonomy.DeleteValueOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02$*\"/enums/{enum_id}/values/{value_id}\x12\xaa\x01\n\x0bUpdateValue\x12!.eolymp.taxonomy.UpdateValueInput\x1a\".eolymp.taxonomy.UpdateValueOutput\"T\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02$\x1a\"/enums/{enum_id}/values/{value_id}\x12\x95\x01\n\rDescribeValue\x12#.eolymp.taxonomy.DescribeValueInput\x1a$.eolymp.taxonomy.DescribeValueOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02$\x12\"/enums/{enum_id}/values/{value_id}\x12\x80\x01\n\nListValues\x12 .eolymp.taxonomy.ListValuesInput\x1a!.eolymp.taxonomy.ListValuesOutput\"-\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x18\x12\x16/enums/{enum_id}/items\x12\xc9\x01\n\x0eTranslateValue\x12$.eolymp.taxonomy.TranslateValueInput\x1a%.eolymp.taxonomy.TranslateValueOutput\"j\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02:\x1a\x38/enums/{enum_id}/values/{value_id}/translations/{locale}\x12\xd2\x01\n\x11\x44\x65leteTranslation\x12\'.eolymp.taxonomy.DeleteTranslationInput\x1a(.eolymp.taxonomy.DeleteTranslationOutput\"j\x82\xe3\n\x17\x8a\xe3\n\x13taxonomy:enum:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02:*8/enums/{enum_id}/values/{value_id}/translations/{locale}\x12\xab\x01\n\x10ListTranslations\x12&.eolymp.taxonomy.ListTranslationsInput\x1a\'.eolymp.taxonomy.ListTranslationsOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x31*//enums/{enum_id}/values/{value_id}/translationsB3Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.taxonomy.enum_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomy'
  _ENUMSERVICE.methods_by_name['CreateEnum']._options = None
  _ENUMSERVICE.methods_by_name['CreateEnum']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\010\"\006/enums'
  _ENUMSERVICE.methods_by_name['DeleteEnum']._options = None
  _ENUMSERVICE.methods_by_name['DeleteEnum']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\022*\020/enums/{enum_id}'
  _ENUMSERVICE.methods_by_name['UpdateEnum']._options = None
  _ENUMSERVICE.methods_by_name['UpdateEnum']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\022\032\020/enums/{enum_id}'
  _ENUMSERVICE.methods_by_name['DescribeEnum']._options = None
  _ENUMSERVICE.methods_by_name['DescribeEnum']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\022\022\020/enums/{enum_id}'
  _ENUMSERVICE.methods_by_name['ListEnums']._options = None
  _ENUMSERVICE.methods_by_name['ListEnums']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\010\022\006/enums'
  _ENUMSERVICE.methods_by_name['CreateValue']._options = None
  _ENUMSERVICE.methods_by_name['CreateValue']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\030\"\026/enums/{enum_id}/items'
  _ENUMSERVICE.methods_by_name['DeleteValue']._options = None
  _ENUMSERVICE.methods_by_name['DeleteValue']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002$*\"/enums/{enum_id}/values/{value_id}'
  _ENUMSERVICE.methods_by_name['UpdateValue']._options = None
  _ENUMSERVICE.methods_by_name['UpdateValue']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002$\032\"/enums/{enum_id}/values/{value_id}'
  _ENUMSERVICE.methods_by_name['DescribeValue']._options = None
  _ENUMSERVICE.methods_by_name['DescribeValue']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002$\022\"/enums/{enum_id}/values/{value_id}'
  _ENUMSERVICE.methods_by_name['ListValues']._options = None
  _ENUMSERVICE.methods_by_name['ListValues']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\030\022\026/enums/{enum_id}/items'
  _ENUMSERVICE.methods_by_name['TranslateValue']._options = None
  _ENUMSERVICE.methods_by_name['TranslateValue']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002:\0328/enums/{enum_id}/values/{value_id}/translations/{locale}'
  _ENUMSERVICE.methods_by_name['DeleteTranslation']._options = None
  _ENUMSERVICE.methods_by_name['DeleteTranslation']._serialized_options = b'\202\343\n\027\212\343\n\023taxonomy:enum:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002:*8/enums/{enum_id}/values/{value_id}/translations/{locale}'
  _ENUMSERVICE.methods_by_name['ListTranslations']._options = None
  _ENUMSERVICE.methods_by_name['ListTranslations']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\0021*//enums/{enum_id}/values/{value_id}/translations'
  _CREATEENUMINPUT._serialized_start=251
  _CREATEENUMINPUT._serialized_end=305
  _CREATEENUMOUTPUT._serialized_start=307
  _CREATEENUMOUTPUT._serialized_end=342
  _DELETEENUMINPUT._serialized_start=344
  _DELETEENUMINPUT._serialized_end=378
  _DELETEENUMOUTPUT._serialized_start=380
  _DELETEENUMOUTPUT._serialized_end=398
  _UPDATEENUMINPUT._serialized_start=401
  _UPDATEENUMINPUT._serialized_end=555
  _UPDATEENUMINPUT_PATCH._serialized_start=529
  _UPDATEENUMINPUT_PATCH._serialized_end=555
  _UPDATEENUMOUTPUT._serialized_start=557
  _UPDATEENUMOUTPUT._serialized_end=575
  _DESCRIBEENUMINPUT._serialized_start=577
  _DESCRIBEENUMINPUT._serialized_end=613
  _DESCRIBEENUMOUTPUT._serialized_start=615
  _DESCRIBEENUMOUTPUT._serialized_end=672
  _LISTENUMSINPUT._serialized_start=675
  _LISTENUMSINPUT._serialized_end=897
  _LISTENUMSINPUT_FILTER._serialized_start=780
  _LISTENUMSINPUT_FILTER._serialized_end=897
  _LISTENUMSOUTPUT._serialized_start=899
  _LISTENUMSOUTPUT._serialized_end=969
  _CREATEVALUEINPUT._serialized_start=971
  _CREATEVALUEINPUT._serialized_end=1045
  _CREATEVALUEOUTPUT._serialized_start=1047
  _CREATEVALUEOUTPUT._serialized_end=1084
  _DELETEVALUEINPUT._serialized_start=1086
  _DELETEVALUEINPUT._serialized_end=1139
  _DELETEVALUEOUTPUT._serialized_start=1141
  _DELETEVALUEOUTPUT._serialized_end=1160
  _UPDATEVALUEINPUT._serialized_start=1163
  _UPDATEVALUEINPUT._serialized_end=1387
  _UPDATEVALUEINPUT_PATCH._serialized_start=1313
  _UPDATEVALUEINPUT_PATCH._serialized_end=1387
  _UPDATEVALUEOUTPUT._serialized_start=1389
  _UPDATEVALUEOUTPUT._serialized_end=1408
  _DESCRIBEVALUEINPUT._serialized_start=1410
  _DESCRIBEVALUEINPUT._serialized_end=1481
  _DESCRIBEVALUEOUTPUT._serialized_start=1483
  _DESCRIBEVALUEOUTPUT._serialized_end=1543
  _LISTVALUESINPUT._serialized_start=1546
  _LISTVALUESINPUT._serialized_end=1803
  _LISTVALUESINPUT_FILTER._serialized_start=780
  _LISTVALUESINPUT_FILTER._serialized_end=897
  _LISTVALUESOUTPUT._serialized_start=1805
  _LISTVALUESOUTPUT._serialized_end=1877
  _TRANSLATEVALUEINPUT._serialized_start=1880
  _TRANSLATEVALUEINPUT._serialized_end=2009
  _TRANSLATEVALUEOUTPUT._serialized_start=2011
  _TRANSLATEVALUEOUTPUT._serialized_end=2033
  _DELETETRANSLATIONINPUT._serialized_start=2035
  _DELETETRANSLATIONINPUT._serialized_end=2110
  _DELETETRANSLATIONOUTPUT._serialized_start=2112
  _DELETETRANSLATIONOUTPUT._serialized_end=2137
  _LISTTRANSLATIONSINPUT._serialized_start=2140
  _LISTTRANSLATIONSINPUT._serialized_end=2352
  _LISTTRANSLATIONSINPUT_FILTER._serialized_start=2294
  _LISTTRANSLATIONSINPUT_FILTER._serialized_end=2352
  _LISTTRANSLATIONSOUTPUT._serialized_start=2354
  _LISTTRANSLATIONSOUTPUT._serialized_end=2444
  _ENUMSERVICE._serialized_start=2447
  _ENUMSERVICE._serialized_end=4529
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/feed/feed_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.feed import entry_pb2 as eolymp_dot_feed_dot_entry__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/feed/feed_service.proto\x12\x0b\x65olymp.feed\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x17\x65olymp/feed/entry.proto\"/\n\x10ListEntriesInput\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\"_\n\x11ListEntriesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12!\n\x05items\x18\x02 \x03(\x0b\x32\x12.eolymp.feed.Entry\x12\x18\n\x10next_page_cursor\x18\x03 \x01(\t2y\n\x0b\x46\x65\x65\x64Service\x12j\n\x0bListEntries\x12\x1d.eolymp.feed.ListEntriesInput\x1a\x1e.eolymp.feed.ListEntriesOutput\"\x1c\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x07\x12\x05/feedB+Z)github.com/eolymp/go-sdk/eolymp/feed;feedb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.feed.feed_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/feed;feed'
  _FEEDSERVICE.methods_by_name['ListEntries']._options = None
  _FEEDSERVICE.methods_by_name['ListEntries']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\007\022\005/feed'
  _LISTENTRIESINPUT._serialized_start=139
  _LISTENTRIESINPUT._serialized_end=186
  _LISTENTRIESOUTPUT._serialized_start=188
  _LISTENTRIESOUTPUT._serialized_end=283
  _FEEDSERVICE._serialized_start=285
  _FEEDSERVICE._serialized_end=406
# @@protoc_insertion_point(module_scope)



from eolymp.community import member_pb2 as _member_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MemberChangeRecord(_message.Message):
    __slots__ = ["member", "op", "space_id"]
    class Operation(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    CREATE: MemberChangeRecord.Operation
    DELETE: MemberChangeRecord.Operation
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    NO_OPERATION: MemberChangeRecord.Operation
    OP_FIELD_NUMBER: _ClassVar[int]
    SPACE_ID_FIELD_NUMBER: _ClassVar[int]
    UPDATE: MemberChangeRecord.Operation
    member: _member_pb2.Member
    op: MemberChangeRecord.Operation
    space_id: str
    def __init__(self, space_id: _Optional[str] = ..., op: _Optional[_Union[MemberChangeRecord.Operation, str]] = ..., member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class MemberCreatedEvent(_message.Message):
    __slots__ = ["member"]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: _member_pb2.Member
    def __init__(self, member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class MemberDeletedEvent(_message.Message):
    __slots__ = ["member"]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: _member_pb2.Member
    def __init__(self, member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...

class MemberUpdatedEvent(_message.Message):
    __slots__ = ["member"]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: _member_pb2.Member
    def __init__(self, member: _Optional[_Union[_member_pb2.Member, _Mapping]] = ...) -> None: ...
